==> imsdk-plus-6.9.3557-sources.jar: com/tencent/imsdk/message/VideoElement.java <==
package com.tencent.imsdk.message;

import com.tencent.imsdk.v2.V2TIMMessage;

public class VideoElement extends MessageBaseElement {
    private String videoUUID;
    private String videoType;
    private String videoFilePath;
    private int videoFileSize;
    private int videoDuration;
    private String videoDownloadUrl;
    private int videoDownloadFlag;
    private int videoBusinessID;

    private String snapshotUUID;
    private String snapshotType;
    private String snapshotFilePath;
    private int snapshotFileSize;
    private int snapshotWidth;
    private int snapshotHeight;
    private String snapshotDownloadUrl;
    private int snapshotDownloadFlag;

    public VideoElement() {
        setElementType(V2TIMMessage.V2TIM_ELEM_TYPE_VIDEO);
    }

    public String getVideoUUID() {
        return videoUUID;
    }

    public String getVideoType() {
        return videoType;
    }

    public void setVideoType(String videoType) {
        this.videoType = videoType;
    }

    public String getVideoFilePath() {
        return videoFilePath;
    }

    public void setVideoFilePath(String videoFilePath) {
        this.videoFilePath = videoFilePath;
    }

    public int getVideoFileSize() {
        return videoFileSize;
    }

    public int getVideoDuration() {
        return videoDuration;
    }

    public void setVideoDuration(int duration) {
        this.videoDuration = duration;
    }

    public int getVideoDownloadFlag() {
        return videoDownloadFlag;
    }

    public String getVideoDownloadUrl() {
        return videoDownloadUrl;
    }

    public int getVideoBusinessID() {
        return videoBusinessID;
    }

    public String getSnapshotUUID() {
        return snapshotUUID;
    }

    public String getSnapshotType() {
        return snapshotType;
    }

    public String getSnapshotFilePath() {
        return snapshotFilePath;
    }

    public void setSnapshotFilePath(String snapshotFilePath) {
        this.snapshotFilePath = snapshotFilePath;
    }

    public int getSnapshotFileSize() {
        return snapshotFileSize;
    }

    public int getSnapshotWidth() {
        return snapshotWidth;
    }

    public int getSnapshotHeight() {
        return snapshotHeight;
    }

    public int getSnapshotDownloadFlag() {
        return snapshotDownloadFlag;
    }

    public String getSnapshotDownloadUrl() {
        return snapshotDownloadUrl;
    }

    @Override
    public boolean update(MessageBaseElement element) {
        if (elementType == element.elementType) {
            VideoElement videoElement = (VideoElement)element;
            if (videoFilePath.equals(videoElement.videoFilePath) && snapshotFilePath.equals(videoElement.snapshotFilePath)) {
                videoUUID = videoElement.videoUUID;
                videoType = videoElement.videoType;
                videoFileSize = videoElement.videoFileSize;
                videoDuration = videoElement.videoDuration;
                videoDownloadUrl = videoElement.videoDownloadUrl;
                videoDownloadFlag = videoElement.videoDownloadFlag;
                videoBusinessID = videoElement.videoBusinessID;

                snapshotUUID = videoElement.snapshotUUID;
                snapshotType = videoElement.snapshotType;
                snapshotFileSize = videoElement.snapshotFileSize;
                snapshotWidth = videoElement.snapshotWidth;
                snapshotHeight = videoElement.snapshotHeight;
                snapshotDownloadUrl = videoElement.snapshotDownloadUrl;
                snapshotDownloadFlag = videoElement.snapshotDownloadFlag;

                return true;
            }
        }

        return false;
    }
}

==> imsdk-plus-7.9.5680-sources.jar: com/tencent/imsdk/message/VideoElement.java <==
package com.tencent.imsdk.message;

import com.tencent.imsdk.v2.V2TIMMessage;

public class VideoElement extends MessageBaseElement {
    private String videoUUID;
    private String videoType;
    private String videoFilePath;
    private int videoFileSize;
    private int videoDuration;
    private String videoDownloadUrl;
    private int videoBusinessID;

    private String snapshotUUID;
    private String snapshotType;
    private String snapshotFilePath;
    private int snapshotFileSize;
    private int snapshotWidth;
    private int snapshotHeight;
    private String snapshotDownloadUrl;

    public VideoElement() {
        setElementType(V2TIMMessage.V2TIM_ELEM_TYPE_VIDEO);
    }

    public String getVideoUUID() {
        return videoUUID;
    }

    public String getVideoType() {
        return videoType;
    }

    public void setVideoType(String videoType) {
        this.videoType = videoType;
    }

    public String getVideoFilePath() {
        return videoFilePath;
    }

    public void setVideoFilePath(String videoFilePath) {
        this.videoFilePath = videoFilePath;
    }

    public int getVideoFileSize() {
        return videoFileSize;
    }

    public int getVideoDuration() {
        return videoDuration;
    }

    public void setVideoDuration(int duration) {
        this.videoDuration = duration;
    }

    public String getVideoDownloadUrl() {
        return videoDownloadUrl;
    }

    public int getVideoBusinessID() {
        return videoBusinessID;
    }

    public String getSnapshotUUID() {
        return snapshotUUID;
    }

    public String getSnapshotType() {
        return snapshotType;
    }

    public String getSnapshotFilePath() {
        return snapshotFilePath;
    }

    public void setSnapshotFilePath(String snapshotFilePath) {
        this.snapshotFilePath = snapshotFilePath;
    }

    public int getSnapshotFileSize() {
        return snapshotFileSize;
    }

    public int getSnapshotWidth() {
        return snapshotWidth;
    }

    public int getSnapshotHeight() {
        return snapshotHeight;
    }

    public String getSnapshotDownloadUrl() {
        return snapshotDownloadUrl;
    }

    @Override
    public boolean update(MessageBaseElement element) {
        if (elementType == element.elementType) {
            VideoElement videoElement = (VideoElement) element;
            if (videoFilePath.equals(videoElement.videoFilePath)
                && snapshotFilePath.equals(videoElement.snapshotFilePath)) {
                videoUUID = videoElement.videoUUID;
                videoType = videoElement.videoType;
                videoFileSize = videoElement.videoFileSize;
                videoDuration = videoElement.videoDuration;
                videoDownloadUrl = videoElement.videoDownloadUrl;
                videoBusinessID = videoElement.videoBusinessID;

                snapshotUUID = videoElement.snapshotUUID;
                snapshotType = videoElement.snapshotType;
                snapshotFileSize = videoElement.snapshotFileSize;
                snapshotWidth = videoElement.snapshotWidth;
                snapshotHeight = videoElement.snapshotHeight;
                snapshotDownloadUrl = videoElement.snapshotDownloadUrl;

                return true;
            }
        }

        return false;
    }
}
